#!/usr/bin/python2

# http://wpitchoune.net/mp3tohtml
# Released under the terms of the GPLv2 license.
# (c) 2016 Jean-Philippe Orsini <jeanfi@gmail.com>

import eyeD3
import fnmatch
import glob
import os
import re
import sys

def fma_copyright_to_html(path, copyright):
    if copyright == "":
        sys.stderr.write(path + ": no FMA copyright.\n")
        return ""

    p = re.compile("(.*): (.*)")
    m = p.match(copyright)
    if m is not None:
        name = m.group(1)
        name = name.replace("Creative Commons", "CC")
        name = name.replace("Attribution", "BY")
        name = name.replace("NonCommercial", "NC")
        name = name.replace("Noncommercial", "NC")
        name = name.replace("NoDerivatives", "ND")
        name = name.replace("ShareAlike", "SA")
        name = name.replace("Share Alike", "SA")
        name = name.replace("United States", "US")
        return "<a href=\"" + m.group(2) + "\">" + name + "</a>"
    else:
        sys.stderr.write(path + ": invalid FMA copyright: "
                         + copyright + ".\n");
        return copyright

def copy_header(path):
    header_path = path + "/header.tpl"
    try:
        header = open(header_path, "r")
        for line in header:
            sys.stdout.write(line)
        header.close()
    except IOError as e:
        sys.stderr.write("Failed to read header file "
                         + header_path
                         + ": " + e.strerror + "\n")
        raise

def copy_footer(path):
    footer_path = path + "/footer.tpl"
    try:
        footer = open(footer_path, "r")
        for line in footer:
            sys.stdout.write(line)
        footer.close()
    except IOError as e:
        sys.stderr.write("Failed to read footer file "
                         + footer_path
                         + ": " + e.strerror + "\n")
        raise

def generate(mp3_dir, cfg_dir):
    copy_header(cfg_dir)

    files = []
    for root, dirnames, filenames in os.walk(mp3_dir):
        for filename in fnmatch.filter(filenames, '*.mp3'):
            files.append(os.path.join(root, filename))

    for f in files:
        tag = eyeD3.Tag()

        tag.link(f)

        print("\t<tr>")

        print("\t\t<td>" + tag.getArtist().encode("UTF8") + "</td>\n")
        print("\t\t<td>" + tag.getAlbum().encode("UTF-8") + "</td>")
        print("\t\t<td>" + tag.getTitle().encode("UTF-8") + "</td>")

        comments = tag.getComments()
        strComments = ""
        for c in comments:
            strComments += c.comment

        p = re.compile("URL: (.*)\r\nComments: (.*)\r\nCurators?: (.*)\r\nCopyright: (.*)")
        m = p.match(strComments)

        if m is None:
            url = ""
            curator = ""
            copyright = ""
        else:
            if m.group(2) == "http://freemusicarchive.org/":
                strComments = ""
                url = "<a href=\"" + m.group(1) + "\">FMA</a>"
            else:
                strComments =  m.group(2)
                url = "<a href=\"" + m.group(1) + "\">source</a>"

            curator = m.group(3)

            copyright = fma_copyright_to_html(f, m.group(4))

        print("\t\t<td>" + url + "</td>")
        print("\t\t<td>" + curator + "</td>")
        print("\t\t<td>" + copyright + "</td>")
        print("\t\t<td>" + strComments + "</td>")

        print("\t</tr>")

    copy_footer(cfg_dir)
